#Determine patch quality based on a vector of four suitability indices.
HSIgeomean(c(0.25, 0.25, 0.25, 0.25))
#Determine patch quality based on a vector of suitability indices with an NA.
HSIgeomean(c(0.25, 0.25, NA, 0.25))
#Determine patch quality based on a vector of suitability indices with a zero-value.
HSIgeomean(c(0.25, 0.25, 0.0, 0.25))
Run the code above in your browser using DataLab