| HSIwarimean | R Documentation |
HSIwarimean uses a weighted arithmetic mean to combine suitability
indices into an overarching habitat suitability index.
HSIwarimean(x, w)
x |
is a vector of suitability indices ranging from 0 to 1. |
w |
is a vector of weights (0 to 1 values that must sum to one). |
A value of habitat quality from 0 to 1 ignoring NA values.
US Fish and Wildlife Service. (1980). Habitat as a basis for environmental assessment. Ecological Services Manual, 101.
US Fish and Wildlife Service. (1980). Habitat Evaluation Procedures (HEP). Ecological Services Manual, 102.
US Fish and Wildlife Service. (1981). Standards for the Development of Habitat Suitability Index Models. Ecological Services Manual, 103.
#Determine patch quality based on a vector of four, equal-weight suitability indices.
HSIwarimean(c(1, 0, 0, 0), c(0.25, 0.25, 0.25, 0.25))
#Determine patch quality based on a vector of four, unequal-weight suitability indices.
HSIwarimean(c(1, 0, 0, 0), c(1, 0, 0, 0))
#Determine patch quality based on a vector of four, unequal-weight suitability indices.
HSIwarimean(c(1, 0, 0, 0), c(0, 1, 0, 0))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.