| HUcalc | R Documentation |
HUcalc computes habitat units given a set of suitability indices,
a habitat suitability index equation, and habitat quantity.
HUcalc(SI.out, habitat.quantity, HSIfunc, ...)
SI.out |
is a vector of application-specific suitability indices between 0 and 1, which can be produced from SIcalc. |
habitat.quantity |
is a numeric of habitat size associated with these suitability indices (i.e., length, area, or volume). |
HSIfunc |
is a function used to combine suitability indices into a composite habitat suitability index (HSI score) (e.g., ecorest functions like HSIarimean or HSIgeomean or functions outside ecorest like max or mean) |
... |
optional arguments to HSIfunc. |
A vector of habitat quality, habitat quantity, and index units (quantity times quality).
US Fish and Wildlife Service. (1980). Habitat as a basis for environmental assessment. Ecological Services Manual, 101.
US Fish and Wildlife Service. (1980). Habitat Evaluation Procedures (HEP). Ecological Services Manual, 102.
US Fish and Wildlife Service. (1981). Standards for the Development of Habitat Suitability Index Models. Ecological Services Manual, 103.
#Summarize habitat outcomes based on a vector of two suitability indices
#using multiple combination equations.
HUcalc(c(0.1,1), 100, HSIarimean)
HUcalc(c(0.1,1), 100, HSIgeomean)
HUcalc(c(0.1,1), 100, HSImin)
HUcalc(c(0.1,1), 100, HSIwarimean, c(1,0))
HUcalc(c(0.1,1), 100, HSIwarimean, c(0,1))
#HSIfunc can also represent functions outside of the ecorest package
HUcalc(c(0.1,1), 100, mean)
HUcalc(c(0.1,1), 100, max)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.