#Determine patch quality based on a vector of four, equal-weight suitability indices.
HSIwarimean(c(1, 0, 0, 0), c(0.25, 0.25, 0.25, 0.25))
#Determine patch quality based on a vector of four, unequal-weight suitability indices.
HSIwarimean(c(1, 0, 0, 0), c(1, 0, 0, 0))
#Determine patch quality based on a vector of four, unequal-weight suitability indices.
HSIwarimean(c(1, 0, 0, 0), c(0, 1, 0, 0))
Run the code above in your browser using DataLab